@@ -4,6 +4,8 @@ import apt_pkg
 import logging
 import unittest
 
+apt_pkg.config.set("Dir", "./aptroot")
+
 import unattended_upgrade
 from unattended_upgrade import (
     check_changes_for_sanity,
@@ -31,6 +33,10 @@ class MockCache(dict):
         for pkgname in self.keys():
             yield self[pkgname]
 
+    def get_changes(self):
+        for pkgname in self.keys():
+            yield self[pkgname]
+
 
 class MockDepCache():
     pass
@@ -64,7 +70,7 @@ class TestOriginPatern(unittest.TestCase):
         # with escaping
         origin = self._get_mock_origin("Google, Inc.", archive="stable")
         # good
-        s = "o=Google\, Inc.,a=stable"
+        s = "o=Google\\, Inc.,a=stable"
         self.assertTrue(match_whitelist_string(s, origin))
 
     def test_match_whitelist_from_conffile(self):
@@ -76,7 +82,7 @@ class TestOriginPatern(unittest.TestCase):
         #print allowed_origins
         self.assertTrue("o=aOrigin,a=aArchive" in allowed_origins)
         self.assertTrue("s=aSite,l=aLabel" in allowed_origins)
-        self.assertTrue("o=Google\, Inc.,suite=stable" in allowed_origins)
+        self.assertTrue("o=Google\\, Inc.,suite=stable" in allowed_origins)
 
     def test_macro(self):
         codename = get_distro_codename()
@@ -90,12 +96,20 @@ class TestOriginPatern(unittest.TestCase):
             apt_pkg.config, "./data/50unattended-upgrades.compat")
         allowed_origins = unattended_upgrade.get_allowed_origins()
         #print allowed_origins
-        self.assertTrue("o=Google\, Inc.,a=stable" in allowed_origins)
-        self.assertTrue("o=MoreCorp\, eink,a=stable" in allowed_origins)
+        self.assertTrue("o=Google\\, Inc.,a=stable" in allowed_origins)
+        self.assertTrue("o=MoreCorp\\, eink,a=stable" in allowed_origins)
         # test whitelist
         pkg = self._get_mock_package()
         self.assertTrue(is_allowed_origin(pkg.candidate, allowed_origins))
 
+    def test_escaped_colon(self):
+        apt_pkg.config.clear("Unattended-Upgrade")
+        apt_pkg.read_config_file(
+            apt_pkg.config, "./data/50unattended-upgrades.colon")
+        allowed_origins = unattended_upgrade.get_allowed_origins()
+
+        self.assertIn('o=http://foo.bar,a=stable', allowed_origins)
+
     def test_unkown_matcher(self):
         apt_pkg.config.clear("Unattended-Upgrade")
         s = "xxx=OriginUbuntu"
@@ -140,6 +154,7 @@ class TestOriginPatern(unittest.TestCase):
         cache = MockCache()
         cache._depcache = MockDepCache()
         cache._depcache.broken_count = 0
+        cache.install_count = 1
         return cache
 
     def _get_mock_origin(self, aorigin="", label="", archive="",
@@ -184,6 +199,20 @@ class TestOriginPatern(unittest.TestCase):
         s = "o=*Ubunt?"
         self.assertTrue(match_whitelist_string(s, origin))
 
+    def test_get_allowed_origins_legacy(self):
+        for cfg, (distro_id, distro_codename) in (
+                # ":" as separator
+                ("Ubuntu:lucid-security", ("Ubuntu", "lucid-security")),
+                ("http\\://foo.bar:stable", ("http://foo.bar", "stable")),
+                # space as separator
+                ("Ubuntu lucid-security", ("Ubuntu", "lucid-security")),
+                ("http\\://baz.mee stable", ("http://baz.mee", "stable"))):
+            apt_pkg.config.clear("Unattended-Upgrade::Allowed-Origins")
+            apt_pkg.config.set("Unattended-Upgrade::Allowed-Origins::", cfg)
+            li = unattended_upgrade.get_allowed_origins_legacy()
+            self.assertEqual(len(li), 1)
+            self.assertEqual(li[0], "o=%s,a=%s" % (distro_id, distro_codename))
+
 
 if __name__ == "__main__":
     logging.basicConfig(level=logging.DEBUG)
