@@ -1,8 +1,10 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 import os
 import unittest
 
+import apt_pkg
+apt_pkg.config.set("Dir", "./aptroot")
 import apt
 
 import unattended_upgrade
@@ -13,9 +15,10 @@ apt.apt_pkg.config.set("APT::Architecture", "amd64")
 class MockOptions(object):
     debug = False
     verbose = False
+    download_only = False
     dry_run = True
     apt_debug = False
-    minimal_upgrade_steps = False
+    minimal_upgrade_steps = True
 
 
 class TestRewindCache(unittest.TestCase):
@@ -32,11 +35,10 @@ class TestRewindCache(unittest.TestCase):
     def test_rewind_cache(self):
         """ Test that rewinding the cache works correctly, debian #743594 """
         options = MockOptions()
-        blacklisted_pkgs = []
-        whitelisted_pkgs = []
+        blacklist = []
+        whitelist = []
         to_upgrade, kept_back = unattended_upgrade.calculate_upgradable_pkgs(
-            self.cache, options, self.allowed_origins, blacklisted_pkgs,
-            whitelisted_pkgs)
+            self.cache, options, self.allowed_origins, blacklist, whitelist)
         self.assertEqual(to_upgrade, [self.cache["test-package"]])
         self.assertEqual(kept_back, ["z-package"])
 
